==> if-admin-layout-1.0.3.tgz: package/src/layout/store.js <==
const isObject = obj => {
    if(obj === null) return false
    if(obj instanceof Array) return false
    return typeof obj === 'object'
}

const setData = (target, key, newVal) => {
    if(isObject(newVal)) {
        Object.keys(newVal).map(_key => {
            setData(target[key], _key, newVal[_key])
        })
    } else {
        target[key] = newVal
    }
}

export default {
    namespaced: true,
    state: {
        name: 'if-layout-config',
        version: '1.0.0',
        // 导航栏高度
        navbar: {
            height: '50px',
        },
        // 尺寸
        sidebar: {
            // 默认高度
            width: '200px',
            minWidth: '63px',
        },
        menuStyle: {
            activeTextColor:"#ffd04b",
            backgroundColor:"#333",
            textColor:"#fff"
        },
        // 是否折叠
        collapse: false,
        // 网站基础信息相关
        SiteInfo: {
            title: "小红马",
            logo: "https://wpimg.wallstcn.com/69a1c46c-eb1c-4b46-8bd4-e9e686ef5251.png",
            siteUrl: '/'
        },
        routes: []
        
    },
    mutations: {
        updateConfig(state, payload) {
            Object.keys(payload).map(key => {
                if(isObject(payload[key])){
                    setData(state, key,  payload[key])
                } else {
                    state[key] = payload[key]
                }
            })
        },
        setRoutes(state, routes) {
            state.routes = routes
        }
    },
    getters: {
        sidebarHeight(state) {
            return `calc(100% - ${state.navbar.height})`
        },
        sidebarWidth(state){
            return state.collapse ? state.sidebar.minWidth : state.sidebar.width
        },
        routes(state) {
            return state.routes
        }
    }
}

==> if-admin-layout-1.0.4.tgz: package/src/layout/store.js <==
const isObject = obj => {
    if(obj === null) return false
    if(obj instanceof Array) return false
    return typeof obj === 'object'
}

const setData = (target, key, newVal) => {
    if(isObject(newVal)) {
        Object.keys(newVal).map(_key => {
            setData(target[key], _key, newVal[_key])
        })
    } else {
        target[key] = newVal
    }
}

export default {
    namespaced: true,
    state: {
        name: 'if-layout-config',
        version: '1.0.0',
        // 导航栏高度
        navbar: {
            height: '50px',
        },
        // 尺寸
        sidebar: {
            // 默认高度
            width: '200px',
            minWidth: '63px',
        },
        menuStyle: {
            activeTextColor:"#333",
            activeBackgroundColor: '#eee',
            backgroundColor:"#333",
            textColor:"#fff"
            // --el-menu-active-color
        },
        // 是否折叠
        collapse: false,
        // 网站基础信息相关
        SiteInfo: {
            title: "小红马",
            logo: "https://wpimg.wallstcn.com/69a1c46c-eb1c-4b46-8bd4-e9e686ef5251.png",
            siteUrl: '/'
        },
        routes: []
        
    },
    mutations: {
        updateConfig(state, payload) {
            Object.keys(payload).map(key => {
                if(isObject(payload[key])){
                    setData(state, key,  payload[key])
                } else {
                    state[key] = payload[key]
                }
            })
        },
        setRoutes(state, routes) {
            state.routes = routes
        }
    },
    getters: {
        sidebarHeight(state) {
            return `calc(100% - ${state.navbar.height})`
        },
        sidebarWidth(state){
            return state.collapse ? state.sidebar.minWidth : state.sidebar.width
        },
        
        stylesBase(state) {
            return {
                '--el-menu-active-background-color': state.activeBackgroundColor,
                '--el-menu-active-color': state.activeTextColor
            }
        },
        routes(state) {
            return state.routes
        }
    }
}
